==> com.liferay.portal.security.ldap-2.0.11-sources.jar: com/liferay/portal/security/ldap/internal/UserImportTransactionThreadLocal.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.security.ldap.internal;

import com.liferay.portal.kernel.util.AutoResetThreadLocal;
import com.liferay.portal.kernel.util.InitialThreadLocal;
import com.liferay.portal.kernel.util.StringPool;

/**
 * @author Edward Han
 * @author Vilmos Papp
 */
public class UserImportTransactionThreadLocal {

	public static String getOriginalEmailAddress() {
		return _originalEmailAddress.get();
	}

	public static boolean isOriginatesFromImport() {
		return _originatesFromImport.get();
	}

	public static void setOriginalEmailAddress(String originalEmailAddress) {
		_originalEmailAddress.set(originalEmailAddress);
	}

	public static void setOriginatesFromImport(boolean originatesFromImport) {
		_originatesFromImport.set(originatesFromImport);
	}

	private static final ThreadLocal<String> _originalEmailAddress =
		new AutoResetThreadLocal<String>(
			UserImportTransactionThreadLocal.class + "._originalEmailAddress",
			StringPool.BLANK);
	private static final ThreadLocal<Boolean> _originatesFromImport =
		new InitialThreadLocal<Boolean>(
			UserImportTransactionThreadLocal.class + "._originatesFromImport",
			false);

}

==> com.liferay.portal.security.ldap-2.2.4-sources.jar: com/liferay/portal/security/ldap/internal/UserImportTransactionThreadLocal.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.security.ldap.internal;

import com.liferay.portal.kernel.util.AutoResetThreadLocal;
import com.liferay.portal.kernel.util.InitialThreadLocal;
import com.liferay.portal.kernel.util.StringPool;

/**
 * @author Edward Han
 * @author Vilmos Papp
 */
public class UserImportTransactionThreadLocal {

	public static String getOriginalEmailAddress() {
		return _originalEmailAddress.get();
	}

	public static boolean isOriginatesFromImport() {
		return _originatesFromImport.get();
	}

	public static void setOriginalEmailAddress(String originalEmailAddress) {
		_originalEmailAddress.set(originalEmailAddress);
	}

	public static void setOriginatesFromImport(boolean originatesFromImport) {
		_originatesFromImport.set(originatesFromImport);
	}

	private static final ThreadLocal<String> _originalEmailAddress =
		new AutoResetThreadLocal<>(
			UserImportTransactionThreadLocal.class + "._originalEmailAddress",
			() -> StringPool.BLANK);
	private static final ThreadLocal<Boolean> _originatesFromImport =
		new InitialThreadLocal<>(
			UserImportTransactionThreadLocal.class + "._originatesFromImport",
			() -> Boolean.FALSE);

}
